==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkImageIdealLowPass.java <==
// java wrapper for vtkImageIdealLowPass object
//

package vtk;
import vtk.*;

public class vtkImageIdealLowPass extends vtkThreadedImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCutOff_2(double id0,double id1,double id2);
  public void SetCutOff(double id0,double id1,double id2)
    { SetCutOff_2(id0,id1,id2); }

  private native void SetCutOff_3(double id0[]);
  public void SetCutOff(double id0[])
    { SetCutOff_3(id0); }

  private native void SetCutOff_4(double id0);
  public void SetCutOff(double id0)
    { SetCutOff_4(id0); }

  private native void SetXCutOff_5(double id0);
  public void SetXCutOff(double id0)
    { SetXCutOff_5(id0); }

  private native void SetYCutOff_6(double id0);
  public void SetYCutOff(double id0)
    { SetYCutOff_6(id0); }

  private native void SetZCutOff_7(double id0);
  public void SetZCutOff(double id0)
    { SetZCutOff_7(id0); }

  private native double[] GetCutOff_8();
  public double[] GetCutOff()
    { return GetCutOff_8(); }

  private native double GetXCutOff_9();
  public double GetXCutOff()
    { return GetXCutOff_9(); }

  private native double GetYCutOff_10();
  public double GetYCutOff()
    { return GetYCutOff_10(); }

  private native double GetZCutOff_11();
  public double GetZCutOff()
    { return GetZCutOff_11(); }

  public vtkImageIdealLowPass() { super(); }

  public vtkImageIdealLowPass(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-aarch64.pkg.tar.xz: vtk/vtkImageIdealLowPass.java <==
// java wrapper for vtkImageIdealLowPass object
//

package vtk;
import vtk.*;

public class vtkImageIdealLowPass extends vtkThreadedImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCutOff_2(double id0,double id1,double id2);
  public void SetCutOff(double id0,double id1,double id2)
    { SetCutOff_2(id0,id1,id2); }

  private native void SetCutOff_3(double id0[]);
  public void SetCutOff(double id0[])
    { SetCutOff_3(id0); }

  private native void SetCutOff_4(double id0);
  public void SetCutOff(double id0)
    { SetCutOff_4(id0); }

  private native void SetXCutOff_5(double id0);
  public void SetXCutOff(double id0)
    { SetXCutOff_5(id0); }

  private native void SetYCutOff_6(double id0);
  public void SetYCutOff(double id0)
    { SetYCutOff_6(id0); }

  private native void SetZCutOff_7(double id0);
  public void SetZCutOff(double id0)
    { SetZCutOff_7(id0); }

  private native double[] GetCutOff_8();
  public double[] GetCutOff()
    { return GetCutOff_8(); }

  private native double GetXCutOff_9();
  public double GetXCutOff()
    { return GetXCutOff_9(); }

  private native double GetYCutOff_10();
  public double GetYCutOff()
    { return GetYCutOff_10(); }

  private native double GetZCutOff_11();
  public double GetZCutOff()
    { return GetZCutOff_11(); }

  public vtkImageIdealLowPass() { super(); }

  public vtkImageIdealLowPass(long id) { super(id); }
  public native long   VTKInit();

}
